==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/it.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Procedura guidata di primo avvio",
    "Add your profile information! For example your email is needed to reset your password." : "Aggiungi le tue informazioni di profilo! Ad esempio, il tuo indirizzo di posta è necessario per ripristinare la password.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Aggiungi le informazioni del tuo profilo! Imposta un'immagine del profilo per una analisi veloce di tutte le funzionalità.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Aggiungi le informazioni del profilo! Imposta un nome completo per una analisi veloce delle funzionalità.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Aggiungi le informazioni del profilo! Imposta un'immagine del profilo per una analisi delle funzionalità.",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Accedi e condividi i tuoi file, i calendari, i contatti, la posta elettronica e altro da qualsiasi dispositivo, alle tue condizioni",
    "Get the apps to sync your files" : "Scarica le applicazioni per sincronizzare i tuoi file",
    "Desktop client" : "Client desktop",
    "Android app" : "Applicazione Android",
    "iOS app" : "Applicazione iOS",
    "Connect your desktop apps to %s" : "Connetti le tue applicazioni desktop a %s",
    "Connect your Calendar" : "Connetti il tuo calendario",
    "Connect your Contacts" : "Connetti i tuoi contatti",
    "Access files via WebDAV" : "Accedi ai file tramite WebDAV",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Ulteriori informazioni sono disponibili nella <a target=\"_blank\" href=\"%s\">documentazione</a> e sul nostro <a target=\"_blank\" href=\"%s\">sito web</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Se ti piace Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud è un ottimo software libero per sincronizzare e condividere i tuoi file. Puoi ottenerlo gratuitamente da https://nextcloud.com\"> consiglialo ai tuoi amici</a>\te <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">dai il tuo contributo</a>!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/it.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Procedura guidata di primo avvio",
    "Add your profile information! For example your email is needed to reset your password." : "Aggiungi le tue informazioni di profilo! Ad esempio, il tuo indirizzo di posta è necessario per ripristinare la password.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Aggiungi le informazioni del tuo profilo! Imposta un'immagine del profilo per una analisi veloce di tutte le funzionalità.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Aggiungi le informazioni del profilo! Imposta un nome completo per una analisi veloce delle funzionalità.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Aggiungi le informazioni del profilo! Imposta un'immagine del profilo per una analisi delle funzionalità.",
    "Get the apps to sync your files" : "Scarica le applicazioni per sincronizzare i tuoi file",
    "Desktop client" : "Client desktop",
    "Android app" : "Applicazione Android",
    "iOS app" : "Applicazione iOS",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Se vuoi supportare il progetto {contributeopen}unisciti allo sviluppo{linkclose} o {contributeopen} diffondi il verbo{linkclose}!",
    "Show First Run Wizard again" : "Mostra nuovamente la procedura di primo avvio",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Accedi e condividi i tuoi file, i calendari, i contatti, la posta elettronica e altro da qualsiasi dispositivo, alle tue condizioni",
    "Connect your desktop apps to %s" : "Connetti le tue applicazioni desktop a %s",
    "Connect your calendar" : "Connetti il tuo calendario",
    "Connect your contacts" : "Connetti i tuoi contatti",
    "Access files via WebDAV" : "Accedi ai file tramite WebDAV",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Ulteriori informazioni sono disponibili nella <a target=\"_blank\" href=\"%s\">documentazione</a> e sul nostro <a target=\"_blank\" href=\"%s\">sito web</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Se ti piace Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud è un ottimo software libero per sincronizzare e condividere i tuoi file. Puoi ottenerlo gratuitamente da https://nextcloud.com\"> consiglialo ai tuoi amici</a>\te <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">dai il tuo contributo</a>!",
    "Connect your Calendar" : "Connetti il tuo calendario",
    "Connect your Contacts" : "Connetti i tuoi contatti"
},
"nplurals=2; plural=(n != 1);");
